@@ -355,7 +355,8 @@ class EncoderDecoderASR(Pretrained):
 
     The class can be used either to run only the encoder (encode()) to extract
     features or to run the entire encoder-decoder model
-    (transcribe()) to transcribe speech.
+    (transcribe()) to transcribe speech. The given YAML must contains the fields
+    specified in the *_NEEDED[] lists.
 
     Example
     -------
@@ -371,10 +372,8 @@ class EncoderDecoderASR(Pretrained):
 
     HPARAMS_NEEDED = ["tokenizer"]
     MODULES_NEEDED = [
-        "compute_features",
-        "normalize",
-        "asr_encoder",
-        "beam_searcher",
+        "encoder",
+        "decoder",
     ]
 
     def __init__(self, *args, **kwargs):
@@ -429,9 +428,7 @@ class EncoderDecoderASR(Pretrained):
         """
         wavs = wavs.float()
         wavs, wav_lens = wavs.to(self.device), wav_lens.to(self.device)
-        feats = self.modules.compute_features(wavs)
-        feats = self.modules.normalize(feats, wav_lens)
-        encoder_out = self.modules.asr_encoder(feats)
+        encoder_out = self.modules.encoder(wavs, wav_lens)
         return encoder_out
 
     def transcribe_batch(self, wavs, wav_lens):
@@ -463,122 +460,7 @@ class EncoderDecoderASR(Pretrained):
         with torch.no_grad():
             wav_lens = wav_lens.to(self.device)
             encoder_out = self.encode_batch(wavs, wav_lens)
-            predicted_tokens, scores = self.modules.beam_searcher(
-                encoder_out, wav_lens
-            )
-            predicted_words = [
-                self.tokenizer.decode_ids(token_seq)
-                for token_seq in predicted_tokens
-            ]
-        return predicted_words, predicted_tokens
-
-
-class TransformerASR(Pretrained):
-    """A ready-to-use Transformer ASR model.
-    The class can be used either to run only the encoder (encode()) to extract
-    features or to run the entire encoder-decoder model
-    (transcribe()) to transcribe speech.
-
-    Example
-    -------
-    >>> from speechbrain.pretrained import TransformerASR
-    >>> tmpdir = getfixture("tmpdir")
-    >>> asr_model = TransformerASR.from_hparams(
-    ...     source="speechbrain/asr-transformer-transformerlm-librispeech",
-    ...     savedir=tmpdir,
-    ... )
-    >>> asr_model.transcribe_file("samples/audio_samples/example2.flac")
-    "MY FATHER HAS REVEALED THE CULPRIT'S NAME"
-    """
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.tokenizer = self.hparams.tokenizer
-
-    def transcribe_file(self, path):
-        """Transcribes the given audiofile into a sequence of words.
-
-        Arguments
-        ---------
-        path : str
-            Path to audio file which to transcribe.
-        Returns
-        -------
-        str
-            The audiofile transcription produced by this ASR system.
-        """
-        waveform = self.load_audio(path)
-        # Fake a batch:
-        batch = waveform.unsqueeze(0)
-        rel_length = torch.tensor([1.0])
-        predicted_words, predicted_tokens = self.transcribe_batch(
-            batch, rel_length
-        )
-        return predicted_words[0]
-
-    def encode_batch(self, wavs, wav_lens):
-        """Encodes the input audio into a sequence of hidden states
-        The waveforms should already be in the model's desired format.
-        You can call:
-        ``normalized = TransformerASR.normalizer(signal, sample_rate)``
-        to get a correctly converted signal in most cases.
-
-        Arguments
-        ---------
-        wavs : torch.tensor
-            Batch of waveforms [batch, time, channels] or [batch, time]
-            depending on the model.
-        wav_lens : torch.tensor
-            Lengths of the waveforms relative to the longest one in the
-            batch, tensor of shape [batch]. The longest one should have
-            relative length 1.0 and others len(waveform) / max_length.
-            Used for ignoring padding.
-
-        Returns
-        -------
-        tensor
-            The encoded batch
-        """
-        torch.Tensor([self.hparams.bos_index])
-        wavs = wavs.float()
-        wavs, wav_lens = wavs.to(self.device), wav_lens.to(self.device)
-        feats = self.modules.compute_features(wavs)
-        normalized = self.modules.normalize(feats, wav_lens)
-        pre_trans_out = self.modules.pre_transformer(normalized)
-        transformer_out = self.modules.transformer.encode(
-            pre_trans_out, wav_lens,
-        )
-        return transformer_out
-
-    def transcribe_batch(self, wavs, wav_lens):
-        """Transcribes the input audio into a sequence of words
-        The waveforms should already be in the model's desired format.
-        You can call:
-        ``normalized = TransformerASR.normalizer(signal, sample_rate)``
-        to get a correctly converted signal in most cases.
-
-        Arguments
-        ---------
-        wavs : torch.tensor
-            Batch of waveforms [batch, time, channels] or [batch, time]
-            depending on the model.
-        wav_lens : torch.tensor
-            Lengths of the waveforms relative to the longest one in the
-            batch, tensor of shape [batch]. The longest one should have
-            relative length 1.0 and others len(waveform) / max_length.
-            Used for ignoring padding.
-
-        Returns
-        -------
-        list
-            Each waveform in the batch transcribed.
-        tensor
-            Each predicted token id.
-        """
-        with torch.no_grad():
-            wav_lens = wav_lens.to(self.device)
-            encoder_out = self.encode_batch(wavs, wav_lens)
-            predicted_tokens, scores = self.modules.beam_searcher(
+            predicted_tokens, scores = self.modules.decoder(
                 encoder_out, wav_lens
             )
             predicted_words = [
@@ -625,7 +507,6 @@ class EncoderClassifier(Pretrained):
         "compute_features",
         "mean_var_norm",
         "embedding_model",
-        "mean_var_norm_emb",
         "classifier",
     ]
 
@@ -676,7 +557,7 @@ class EncoderClassifier(Pretrained):
         feats = self.modules.mean_var_norm(feats, wav_lens)
         embeddings = self.modules.embedding_model(feats, wav_lens)
         if normalize:
-            embeddings = self.modules.mean_var_norm_emb(
+            embeddings = self.hparams.mean_var_norm_emb(
                 embeddings, torch.ones(embeddings.shape[0], device=self.device)
             )
         return embeddings
@@ -988,7 +869,10 @@ class SpectralMaskEnhancement(Pretrained):
             If provided, writes enhanced data to this file.
         """
         noisy = self.load_audio(filename)
-        enhanced = self.enhance_batch(noisy)
+
+        # Fake a batch:
+        batch = noisy.unsqueeze(0)
+        enhanced = self.enhance_batch(batch)
 
         if output_filename is not None:
             torchaudio.save(output_filename, enhanced, channels_first=False)
