@@ -193,7 +193,7 @@ class ISTFT(torch.nn.Module):
 
     This class computes the Inverse Short-Term Fourier Transform of
     an audio signal. It supports multi-channel audio inputs
-    (batch, time_step, n_fft, 2, n_channels [optional]).
+    (batch, time_step, n_fft, n_channels [optional], 2).
 
     Arguments
     ---------
@@ -302,6 +302,9 @@ class ISTFT(torch.nn.Module):
         elif len(or_shape) == 4:
             x = x.permute(0, 2, 1, 3)
 
+        # isft ask complex input
+        x = torch.complex(x[..., 0], x[..., 1])
+
         istft = torch.istft(
             input=x,
             n_fft=n_fft,
@@ -696,9 +699,7 @@ class Filterbank(torch.nn.Module):
         x_db -= self.multiplier * self.db_multiplier
 
         # Setting up dB max
-        new_x_db_max = torch.tensor(
-            float(x_db.max()) - self.top_db, dtype=x_db.dtype, device=x.device,
-        )
+        new_x_db_max = x_db.max() - self.top_db
         # Clipping to dB max
         x_db = torch.max(x_db, new_x_db_max)
 
@@ -1013,7 +1014,7 @@ class InputNormalization(torch.nn.Module):
         for snt_id in range(N_batches):
 
             # Avoiding padded time steps
-            actual_size = int(torch.round(lengths[snt_id] * x.shape[1]))
+            actual_size = torch.round(lengths[snt_id] * x.shape[1]).int()
 
             # computing statistics
             current_mean, current_std = self._compute_current_stats(
